"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vscode_1 = require("vscode");
class Config {
    get storage() {
        return vscode_1.workspace.getConfiguration('gitea', null);
    }
    loadConfigValue(configKey, type, acceptDetault = false) {
        if (!acceptDetault && !this.storage.has(configKey)) {
            vscode_1.window.showErrorMessage("Gitea-VSCode didn't find a required configuration value: " + configKey);
            throw new Error(`Failed to load configuration: "${configKey}"`);
        }
        const value = this.storage.has(configKey)
            ? this.storage.get(configKey)
            : this.storage.inspect(configKey).defaultValue;
        if (typeof value === type && (type !== 'string' || value.length > 0)) {
            return value;
        }
        vscode_1.window.showErrorMessage('Gitea-VSCode failed to load a configuration value that is needed: ' + configKey);
        throw new Error(`Failed to load configuration: "gitea.${configKey}"`);
    }
    get token() {
        return this.loadConfigValue('token', 'string');
    }
    set token(value) {
        this.storage.update('token', value);
    }
    get domain() {
        return this.loadConfigValue('domain', 'string');
    }
    set domain(value) {
        this.storage.update('domain', value);
    }
    get port() {
        return this.loadConfigValue('port', 'number');
    }
    set port(value) {
        this.storage.update('port', value);
    }
    get owner() {
        return this.loadConfigValue('owner', 'string');
    }
    set owner(value) {
        this.storage.update('owner', value);
    }
    get repo() {
        return this.loadConfigValue('repo', 'string');
    }
    set repo(value) {
        this.storage.update('repo', value);
    }
    get ssl() {
        return this.loadConfigValue('ssl', 'boolean', true);
    }
    set ssl(value) {
        this.storage.update('ssl', value);
    }
    get repoApiUrl() {
        if (this.ssl || this.port === 443) {
            return 'https://' + this.domain + '/api/v1/repos/' + this.owner + '/' + this.repo + '/issues';
        }
        return 'http://' + this.domain + ':' + this.port + '/api/v1/repos/' + this.owner + '/' + this.repo + '/issues';
    }
}
exports.Config = Config;
//# sourceMappingURL=Config.js.map